@@ -1,9 +1,8 @@
 from typing import Any, Dict, List, Literal, Sequence, Type
 
 from grai_client.schemas.schema import Schema
-from multimethod import multimethod
-
 from grai_source_postgres.models import ID, Column, Edge, Table
+from multimethod import multimethod
 
 
 @multimethod
@@ -34,7 +33,7 @@ def adapt_column_to_client(current: Column, version: Literal["v1"] = "v1"):
 @adapt_to_client.register
 def adapt_table_to_client(current: Table, version: Literal["v1"] = "v1"):
     metadata = {
-        "node_type": "Table",
+        "node_type": current.table_type,
         "schema": current.table_schema,
     }
     spec_dict = {
