@@ -4,7 +4,6 @@ from typing import Any, Callable, Dict, List, Optional, Union
 
 import psycopg2
 import psycopg2.extras
-
 from grai_source_postgres.models import (
     Column,
     ColumnID,
@@ -88,11 +87,10 @@ class PostgresConnector:
         """
 
         query = """
-            SELECT table_schema, table_name
+            SELECT table_schema, table_name, table_type
             FROM information_schema.tables
             WHERE table_schema != 'pg_catalog'
             AND table_schema != 'information_schema'
-            AND table_type='BASE TABLE'
             ORDER BY table_schema, table_name
         """
         return [
